import { useState } from 'react';
//import { useRouter } from 'next/router';

export default function Home() {
  const [sqlQuery, setSqlQuery] = useState('');
  const [result, setResult] = useState(null);
  const [error, setError] = useState<string | null>(null);
  //const router = useRouter();

  const handleSubmit = async (e: React.FormEvent) => {
    e.preventDefault();
    try {
      const response = await fetch('/api/execute', {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ query: sqlQuery }),
      });

      if (!response.ok) {
        throw new Error('Network response was not ok');
      }

      const data = await response.json();
      if (data.error) {
        setError(data.error);
        setResult(null);
      } else {
        setResult(data.result);
        setError(null);
      }
    } catch (error) {
      if (error instanceof Error) {
        setError(error.message);
      } else {
        setError('An unknown error occurred');
      }
      setResult(null);
    }
  };

  return (
      <div>
        <h1>SQL Query Executor</h1>
        <form onSubmit={handleSubmit}>
        <textarea
            value={sqlQuery}
            onChange={(e) => setSqlQuery(e.target.value)}
            placeholder="Enter your SQL query here"
            rows={10}
            cols={50}
        />
          <br />
          <button type="submit">Execute</button>
        </form>
        {error && <div style={{ color: 'red' }}>Error: {error}</div>}
        {result && (
            <div>
              <h2>Result:</h2>
              <pre>{JSON.stringify(result, null, 2)}</pre>
            </div>
        )}
      </div>
  );
}
